#!/bin/sh

echo 1..2

. `dirname $0`/boilerplate.sh

for enc in C C.UTF-8 ; do
    LC_ALL=$enc
    export LC_ALL

    $SCREEN cat debian/tests/t/bug-982435-CVE-2021-26937.crash > /dev/null 2>&1
    sleep 1
    screen -ls | fgrep -q 'Dead ???'
    check_exit_code_false "No dead session found after triggering a CVE-2021-26937 crash (LC_ALL=$enc)"

    # Cleanup in case of crash
    screen -wipe > /dev/null 2>&1 || true
done
